==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/StepLineSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { HorizontalAnchoredCategorySeriesDescriptionMetadata } from "./HorizontalAnchoredCategorySeriesDescriptionMetadata";
import { StepLineSeriesDescription } from "./StepLineSeriesDescription";
/**
 * @hidden
 */
var StepLineSeriesDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(StepLineSeriesDescriptionMetadata, _super);
    function StepLineSeriesDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    StepLineSeriesDescriptionMetadata.b = function (a) {
        if (StepLineSeriesDescriptionMetadata.a == null) {
            StepLineSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            StepLineSeriesDescriptionMetadata.c(StepLineSeriesDescriptionMetadata.a);
        }
        if (a.g(StepLineSeriesDescriptionMetadata.a)) {
            return;
        }
        a.s(StepLineSeriesDescriptionMetadata.a);
    };
    StepLineSeriesDescriptionMetadata.c = function (a) {
        HorizontalAnchoredCategorySeriesDescriptionMetadata.c(a);
    };
    StepLineSeriesDescriptionMetadata.d = function (a) {
        StepLineSeriesDescriptionMetadata.b(a);
        a.u("StepLineSeries", function () { return new StepLineSeriesDescription(); });
        a.t("StepLineSeries", StepLineSeriesDescriptionMetadata.a);
    };
    StepLineSeriesDescriptionMetadata.$t = markType(StepLineSeriesDescriptionMetadata, 'StepLineSeriesDescriptionMetadata');
    StepLineSeriesDescriptionMetadata.a = null;
    return StepLineSeriesDescriptionMetadata;
}(Base));
export { StepLineSeriesDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/StepLineSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { HorizontalAnchoredCategorySeriesDescriptionMetadata } from "./HorizontalAnchoredCategorySeriesDescriptionMetadata";
import { StepLineSeriesDescription } from "./StepLineSeriesDescription";
/**
 * @hidden
 */
var StepLineSeriesDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(StepLineSeriesDescriptionMetadata, _super);
    function StepLineSeriesDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    StepLineSeriesDescriptionMetadata.b = function (a) {
        if (StepLineSeriesDescriptionMetadata.a == null) {
            StepLineSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            StepLineSeriesDescriptionMetadata.c(StepLineSeriesDescriptionMetadata.a);
        }
        if (a.j(StepLineSeriesDescriptionMetadata.a)) {
            return;
        }
        a.y(StepLineSeriesDescriptionMetadata.a);
    };
    StepLineSeriesDescriptionMetadata.c = function (a) {
        HorizontalAnchoredCategorySeriesDescriptionMetadata.c(a);
    };
    StepLineSeriesDescriptionMetadata.d = function (a) {
        StepLineSeriesDescriptionMetadata.b(a);
        a.aa("StepLineSeries", function () { return new StepLineSeriesDescription(); });
        a.z("StepLineSeries", StepLineSeriesDescriptionMetadata.a);
    };
    StepLineSeriesDescriptionMetadata.$t = markType(StepLineSeriesDescriptionMetadata, 'StepLineSeriesDescriptionMetadata');
    StepLineSeriesDescriptionMetadata.a = null;
    return StepLineSeriesDescriptionMetadata;
}(Base));
export { StepLineSeriesDescriptionMetadata };
